"""Catch all web server to spawn Docker containers."""
from flask import Flask, make_response, request
from containerspawner.state import StateManager

app = Flask(__name__)
state = StateManager()


@app.route("/", defaults={"path": ""})
@app.route("/<path:path>")
def default(path):
    """Catch all endpoint to spawn Docker containers."""
    username = request.headers.get("X-Forwarded-Preferred-User")
    if not username:
        return make_response("No username provided by upstream.", 400)

    if not state.is_running(username):
        state.spawn(username)

    response = make_response(f"Container spawned. Reloading `{path}`...", 201)
    response.headers["Refresh"] = "5"
    return response
